pub struct InPlaceError { /* private fields */ }Expand description
An error that can occur while opening, saving, or discarding an
InPlaceFile.
Some errors are caused by failed I/O operations, while others are responses
to invalid paths or backup specifiers. Only the first kind have source
errors, available via InPlaceError::as_io_error() and
InPlaceError::into_io_error() in addition to
std::error::Error::source().
Implementations
Sourceimpl InPlaceError
impl InPlaceError
Sourcepub fn kind(&self) -> InPlaceErrorKind
pub fn kind(&self) -> InPlaceErrorKind
Returns an enum value describing the operation or check that failed
Sourcepub fn as_io_error(&self) -> Option<&Error>
pub fn as_io_error(&self) -> Option<&Error>
Returns the std::io::Error that occurred, if any. See the
documentation of InPlaceErrorKind to find out which error kinds
have source errors.
Sourcepub fn into_io_error(self) -> Option<Error>
pub fn into_io_error(self) -> Option<Error>
Consumes the InPlaceError and returns the inner std::io::Error,
if any.